@@ -20,11 +20,10 @@
 
 import logging
 
-from telegram_click.const import ARG_NAMING_PREFIXES
-from telegram_click.util import escape_for_markdown, find_duplicates
+from telegram_click.const import ARG_VALUE_SEPARATOR_CHAR
+from telegram_click.util import find_duplicates
 
 LOGGER = logging.getLogger(__name__)
-LOGGER.setLevel(logging.DEBUG)
 
 
 class Argument:
@@ -49,11 +48,9 @@ class Argument:
         for c in name:
             if c.isspace():
                 raise ValueError("Argument name must not contain whitespace!")
-        self.names = [name] if not isinstance(name, list) else name
-        duplicates = find_duplicates(self.names)
-        if len(duplicates) > 0:
-            clashing = ", ".join(duplicates.keys())
-            raise ValueError("Argument names must be unique! Clashing arguments: {}".format(clashing))
+        self.names = [name.strip()] if not isinstance(name, list) else name
+        self.names = list(map(lambda x: x.strip(), self.names))
+        self._validate_names()
 
         self.description = description.strip()
         self.example = example
@@ -98,23 +95,6 @@ class Argument:
                 raise ValueError("Invalid value for argument '{}': '{}'".format(self.names[0], arg))
         return parsed
 
-    def generate_argument_message(self) -> str:
-        """
-        Generates the usage text for this argument
-        :return: usage text line
-        """
-        arg_prefix = next(iter(ARG_NAMING_PREFIXES))
-        arg_names = list(map(lambda x: "`{}{}`".format(arg_prefix, x), self.names))
-
-        message = "  {} (`{}`): {}".format(
-            ", ".join(arg_names),
-            self.type.__name__,
-            escape_for_markdown(self.description)
-        )
-        if self.optional:
-            message += " (`{}`)".format(escape_for_markdown(self.default))
-        return message
-
     @staticmethod
     def _boolean_converter(value: str) -> bool:
         """
@@ -142,6 +122,19 @@ class Argument:
         else:
             return float(value)
 
+    def _validate_names(self):
+        """
+        Validates argument names and raises an exception if something is invalid
+        """
+        for name in self.names:
+            if ARG_VALUE_SEPARATOR_CHAR in name:
+                raise ValueError("Argument names must not contain '=' character: {}".format(name))
+
+        duplicates = find_duplicates(self.names)
+        if len(duplicates) > 0:
+            clashing = ", ".join(duplicates.keys())
+            raise ValueError("Argument names must be unique! Clashing arguments: {}".format(clashing))
+
 
 class Flag(Argument):
     """
